OiRA

Help

1. Preparació
2. Implicació
3. Identificació + Avaluació
4. Pla d'acció
5. Informe
6. Grau d’emplenament 0%

# Informes

Un cop identificats tots els riscos de l'organització i un cop creat un pla d'acció, es pot generar un informe amb tots els resultats. Si vol, pot afegir comentaris addicionals a l'informe al camp que trobarà a continuació.

Desar i continuar

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More